@@ -18,7 +18,7 @@ from fsspec.implementations.hdfs import PyArrowHDFS
 from tqdm import tqdm
 
 from autofaiss.indices.index_utils import _get_index_from_bytes, _get_bytes_from_index
-from autofaiss.readers.embeddings_iterators import get_file_list, get_matrix_reader
+from autofaiss.readers.embeddings_iterators import get_file_list, get_matrix_reader, make_path_absolute
 from autofaiss.utils.cast import cast_memory_to_bytes
 from autofaiss.utils.decorators import Timeit
 
@@ -303,6 +303,12 @@ def run(
     embedding_ids_df_handler: Optional[Callable[[pd.DataFrame, int], Any]]
         The function that handles the embeddings Ids when id_columns is given
     """
+    if isinstance(embeddings_path, str):
+        embeddings_path = make_path_absolute(embeddings_path)
+    else:
+        embeddings_path = list(map(make_path_absolute, embeddings_path))
+    temporary_indices_folder = make_path_absolute(temporary_indices_folder)
+
     ss = _get_pyspark_active_session()
     # broadcast the index bytes
     trained_index_bytes = _get_bytes_from_index(faiss_index)
